summaryrefslogtreecommitdiffstats
path: root/tdecore/kstdaccel.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kstdaccel.h')
-rw-r--r--tdecore/kstdaccel.h116
1 files changed, 58 insertions, 58 deletions
diff --git a/tdecore/kstdaccel.h b/tdecore/kstdaccel.h
index 813255cc3..580204673 100644
--- a/tdecore/kstdaccel.h
+++ b/tdecore/kstdaccel.h
@@ -25,20 +25,20 @@
#include "tdelibs_export.h"
class TQKeyEvent;
-class KAccelActions;
+class TDEAccelActions;
/**
- * \namespace KStdAccel
+ * \namespace TDEStdAccel
* Convenient methods for access to the common accelerator keys in
* the key configuration. These are the standard keybindings that should
* be used in all KDE applications. They will be configurable,
* so do not hardcode the default behavior.
*
* If you want real configurable keybindings in your applications,
* please checkout the class KAccel in kaccel.h
* @see KAccelShortcutList
*/
-namespace KStdAccel
+namespace TDEStdAccel
{
// Always add new std-accels to the end of this enum, never in the middle!
/**
@@ -87,7 +87,7 @@ namespace KStdAccel
* Returns the keybinding for @p accel.
* @param id the id of the accelerator
*/
- TDECORE_EXPORT const KShortcut& shortcut(StdAccel id);
+ TDECORE_EXPORT const TDEShortcut& shortcut(StdAccel id);
/**
* Returns a unique name for the given accel.
@@ -126,326 +126,326 @@ namespace KStdAccel
* @param id the id of the accelerator
* @return the default shortcut of the accelerator
*/
- TDECORE_EXPORT KShortcut shortcutDefault(StdAccel id);
+ TDECORE_EXPORT TDEShortcut shortcutDefault(StdAccel id);
/**
* Returns the hardcoded default 3 modifier shortcut for @p id.
* This does not take into account the user's configuration.
* @param id the id of the accelerator
* @return the default 3 modifier shortcut
*/
- TDECORE_EXPORT KShortcut shortcutDefault3(StdAccel id);
+ TDECORE_EXPORT TDEShortcut shortcutDefault3(StdAccel id);
/**
* Returns the hardcoded default 4 modifier shortcut for @p id.
* This does not take into account the user's configuration.
* @param id the id of the accelerator
* @return the default 4 modifier shortcut
*/
- TDECORE_EXPORT KShortcut shortcutDefault4(StdAccel id);
+ TDECORE_EXPORT TDEShortcut shortcutDefault4(StdAccel id);
/**
* Open file. Default: Ctrl-o
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& open();
+ TDECORE_EXPORT const TDEShortcut& open();
/**
* Create a new document (or whatever). Default: Ctrl-n
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& openNew();
+ TDECORE_EXPORT const TDEShortcut& openNew();
/**
* Close current document. Default: Ctrl-w
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& close();
+ TDECORE_EXPORT const TDEShortcut& close();
/**
* Save current document. Default: Ctrl-s
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& save();
+ TDECORE_EXPORT const TDEShortcut& save();
/**
* Print current document. Default: Ctrl-p
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& print();
+ TDECORE_EXPORT const TDEShortcut& print();
/**
* Quit the program. Default: Ctrl-q
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& quit();
+ TDECORE_EXPORT const TDEShortcut& quit();
/**
* Undo last operation. Default: Ctrl-z
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& undo();
+ TDECORE_EXPORT const TDEShortcut& undo();
/**
* Redo. Default: Shift-Ctrl-z
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& redo();
+ TDECORE_EXPORT const TDEShortcut& redo();
/**
* Cut selected area and store it in the clipboard. Default: Ctrl-x
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& cut();
+ TDECORE_EXPORT const TDEShortcut& cut();
/**
* Copy selected area into the clipboard. Default: Ctrl-c
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& copy();
+ TDECORE_EXPORT const TDEShortcut& copy();
/**
* Paste contents of clipboard at mouse/cursor position. Default: Ctrl-v
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& paste();
+ TDECORE_EXPORT const TDEShortcut& paste();
/**
* Paste the selection at mouse/cursor position. Default: Ctrl-Shift-Insert
* @return the shortcut of the standard accelerator
* @since 3.4
*/
- TDECORE_EXPORT const KShortcut& pasteSelection();
+ TDECORE_EXPORT const TDEShortcut& pasteSelection();
/**
* Reload. Default: Ctrl-A
* @return the shortcut of the standard accelerator
**/
- TDECORE_EXPORT const KShortcut& selectAll();
+ TDECORE_EXPORT const TDEShortcut& selectAll();
/**
* Delete a word back from mouse/cursor position. Default: Ctrl-Backspace
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& deleteWordBack();
+ TDECORE_EXPORT const TDEShortcut& deleteWordBack();
/**
* Delete a word forward from mouse/cursor position. Default: Ctrl-Delete
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& deleteWordForward();
+ TDECORE_EXPORT const TDEShortcut& deleteWordForward();
/**
* Find, search. Default: Ctrl-f
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& find();
+ TDECORE_EXPORT const TDEShortcut& find();
/**
* Find/search next. Default: F3
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& findNext();
+ TDECORE_EXPORT const TDEShortcut& findNext();
/**
* Find/search previous. Default: Shift-F3
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& findPrev();
+ TDECORE_EXPORT const TDEShortcut& findPrev();
/**
* Find and replace matches. Default: Ctrl-r
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& replace();
+ TDECORE_EXPORT const TDEShortcut& replace();
/**
* Zoom in. Default: Ctrl-Plus
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& zoomIn();
+ TDECORE_EXPORT const TDEShortcut& zoomIn();
/**
* Zoom out. Default: Ctrl-Minus
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& zoomOut();
+ TDECORE_EXPORT const TDEShortcut& zoomOut();
/**
* Toggle insert/overwrite (with visual feedback, e.g. in the statusbar). Default: Insert
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& insert();
+ TDECORE_EXPORT const TDEShortcut& insert();
/**
* Goto beginning of the document. Default: Ctrl-Home
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& home();
+ TDECORE_EXPORT const TDEShortcut& home();
/**
* Goto end of the document. Default: Ctrl-End
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& end();
+ TDECORE_EXPORT const TDEShortcut& end();
/**
* Goto beginning of current line. Default: Home
* @return the shortcut of the standard accelerator
* @since 3.3
*/
- TDECORE_EXPORT const KShortcut& beginningOfLine();
+ TDECORE_EXPORT const TDEShortcut& beginningOfLine();
/**
* Goto end of current line. Default: End
* @return the shortcut of the standard accelerator
* @since 3.3
*/
- TDECORE_EXPORT const KShortcut& endOfLine();
+ TDECORE_EXPORT const TDEShortcut& endOfLine();
/**
* Scroll up one page. Default: Prior
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& prior();
+ TDECORE_EXPORT const TDEShortcut& prior();
/**
* Scroll down one page. Default: Next
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& next();
+ TDECORE_EXPORT const TDEShortcut& next();
/**
* Go to line. Default: Ctrl+G
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& gotoLine();
+ TDECORE_EXPORT const TDEShortcut& gotoLine();
/**
* Add current page to bookmarks. Default: Ctrl+B
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& addBookmark();
+ TDECORE_EXPORT const TDEShortcut& addBookmark();
/**
* Next Tab. Default: Ctrl-<
* @return the shortcut of the standard accelerator
* @since 3.2
*/
- TDECORE_EXPORT const KShortcut& tabNext();
+ TDECORE_EXPORT const TDEShortcut& tabNext();
/**
* Previous Tab. Default: Ctrl->
* @return the shortcut of the standard accelerator
* @since 3.2
*/
- TDECORE_EXPORT const KShortcut& tabPrev();
+ TDECORE_EXPORT const TDEShortcut& tabPrev();
/**
* Full Screen Mode. Default: Ctrl+Shift+F
* @return the shortcut of the standard accelerator
* @since 3.2
*/
- TDECORE_EXPORT const KShortcut& fullScreen();
+ TDECORE_EXPORT const TDEShortcut& fullScreen();
/**
* Help the user in the current situation. Default: F1
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& help();
+ TDECORE_EXPORT const TDEShortcut& help();
/**
* Complete text in input widgets. Default Ctrl+E
* @return the shortcut of the standard accelerator
**/
- TDECORE_EXPORT const KShortcut& completion();
+ TDECORE_EXPORT const TDEShortcut& completion();
/**
* Iterate through a list when completion returns
* multiple items. Default: Ctrl+Up
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& prevCompletion();
+ TDECORE_EXPORT const TDEShortcut& prevCompletion();
/**
* Iterate through a list when completion returns
* multiple items. Default: Ctrl+Down
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& nextCompletion();
+ TDECORE_EXPORT const TDEShortcut& nextCompletion();
/**
* Find a string within another string or list of strings.
* Default: Ctrl-T
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& substringCompletion();
+ TDECORE_EXPORT const TDEShortcut& substringCompletion();
/**
* Help users iterate through a list of entries. Default: Up
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& rotateUp();
+ TDECORE_EXPORT const TDEShortcut& rotateUp();
/**
* Help users iterate through a list of entries. Default: Down
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& rotateDown();
+ TDECORE_EXPORT const TDEShortcut& rotateDown();
/**
* popup a context menu. Default: Menu
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& popupMenuContext();
+ TDECORE_EXPORT const TDEShortcut& popupMenuContext();
/**
* What's This button. Default: Shift+F1
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& whatsThis();
+ TDECORE_EXPORT const TDEShortcut& whatsThis();
/**
* Reload. Default: F5
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& reload();
+ TDECORE_EXPORT const TDEShortcut& reload();
/**
* Up. Default: Alt+Up
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& up();
+ TDECORE_EXPORT const TDEShortcut& up();
/**
* Back. Default: Alt+Left
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& back();
+ TDECORE_EXPORT const TDEShortcut& back();
/**
* Forward. Default: ALT+Right
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& forward();
+ TDECORE_EXPORT const TDEShortcut& forward();
/**
* BackwardWord. Default: Ctrl+Left
* @return the shortcut of the standard accelerator
* @since 3.3
*/
- TDECORE_EXPORT const KShortcut& backwardWord();
+ TDECORE_EXPORT const TDEShortcut& backwardWord();
/**
* ForwardWord. Default: Ctrl+Right
* @return the shortcut of the standard accelerator
* @since 3.3
*/
- TDECORE_EXPORT const KShortcut& forwardWord();
+ TDECORE_EXPORT const TDEShortcut& forwardWord();
/**
* Show Menu Bar. Default: Ctrl-M
* @return the shortcut of the standard accelerator
*/
- TDECORE_EXPORT const KShortcut& showMenubar();
+ TDECORE_EXPORT const TDEShortcut& showMenubar();
#if !defined(KDE_NO_COMPAT) && !defined(__KSTDACCEL_CPP_)
/**
@@ -25,20 +25,20 @@
*
* If you want real configurable keybindings in your applications,
- * please checkout the class KAccel in kaccel.h
- * @see KAccelShortcutList
+ * please checkout the class TDEAccel in kaccel.h
+ * @see TDEAccelShortcutList
*/